@@ -1,7 +1,7 @@
 matchit2full <- function(treat, X, data, distance, discarded, is.full.mahalanobis,
                          verbose=FALSE, ...) { 
-  if (!("optmatch" %in% .packages(all = TRUE)))
-    install.packages("optmatch")
+  #if (!("optmatch" %in% .packages(all = TRUE)))
+  #  install.packages("optmatch")
   require(optmatch)
   
   if(verbose)
